.. Songbird-py documentation master file, created by
   sphinx-quickstart on Sat Dec 25 01:32:30 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Songbird-py's documentation!
=======================================

Songbird-py is a python library providing python bindings for Songbird_.

Github_

.. _Github: https://github.com/Lunarmagpie/Songbird-Py


.. _Songbird: https://docs.rs/songbird/latest/songbird/


.. toctree::
   :maxdepth: 2
   :caption: Contents:



Find Stuff Here
===============

* :ref:`genindex`
* :ref:`modindex`

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   hikari
   pincer
   queue
   exceptions
   songbird
